Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5235)

Unified Diff: chrome/browser/ui/fullscreen_controller.h

Issue 10261011: Windowed mode mouse lock addded to fullscreen controller. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/fullscreen_controller.h
diff --git a/chrome/browser/ui/fullscreen_controller.h b/chrome/browser/ui/fullscreen_controller.h
index ea79a51a01c6c1e76793a7ea5057869448715a9c..e5aa1851b9a88d4b0f284952d1361ac5c2263042 100644
--- a/chrome/browser/ui/fullscreen_controller.h
+++ b/chrome/browser/ui/fullscreen_controller.h
@@ -92,13 +92,15 @@ class FullscreenController : public base::RefCounted<FullscreenController> {
virtual ~FullscreenController();
- // Notifies the tab that it has been forced out of fullscreen mode if
- // necessary.
- void NotifyTabOfFullscreenExitIfNecessary();
+ // Notifies the tab that it has been forced out of fullscreen and mouse lock
+ // mode if necessary.
+ void NotifyTabOfExitIfNecessary();
+
// Make the current tab exit fullscreen mode if it is in it.
void ExitTabbedFullscreenModeIfNecessary();
void UpdateFullscreenExitBubbleContent();
void NotifyFullscreenChange();
+ void NotifyMouseLockChange();
ContentSetting GetFullscreenSetting(const GURL& url) const;
ContentSetting GetMouseLockSetting(const GURL& url) const;
@@ -125,6 +127,11 @@ class FullscreenController : public base::RefCounted<FullscreenController> {
// clicking the allow button on the fullscreen infobar.
bool tab_fullscreen_accepted_;
+ bool in_or_entering_fullscreen_;
yzshen1 2012/04/30 19:32:40 [something to consider/discuss] As the state gets
scheib 2012/05/01 03:27:07 ValidateState() is an interesting idea. It would a
+
+ // Wrapper for current tab with mouse lock.
+ TabContentsWrapper* mouse_lock_tab_;
yzshen1 2012/04/30 19:32:40 Maybe add comment that |mouse_lock_tab_| is not NU
scheib 2012/05/01 03:27:07 Done.
+
MouseLockState mouse_lock_state_;
DISALLOW_COPY_AND_ASSIGN(FullscreenController);

Powered by Google App Engine
This is Rietveld 408576698